#include "utils.h"

void makeNelectrons(){

  gROOT->Reset();
  gROOT->SetStyle("Plain");

  //* ATLAS Style:
  gROOT->SetStyle("ATLAS");
  gROOT->ForceStyle();
  
  const int numDataPoints=50;
  double BinSIZE      [numDataPoints];
  for (int i=0; i<numDataPoints; i++) {
    BinSIZE[i]=0.0;
  }

  // Michael's data:
  //#define RFACTOR   24.0/74.0;
  //#define RFACTOR10 24.0/69.0;

  // Kerry's data:
#define RFACTOR   1;//22.5/30.;
#define RFACTOR10 1;//22.5/30.;
#define VSYSTEMATIC 0.2;// due to the fit range (200 electrons)


  float etaBinSize[numDataPoints];
  
  FILE *inputFile = NULL;
  //* Baseline File:
  char fileName[120]="./inputFile.txt"; //-23oC

  
  double volts[numDataPoints];
  double errVolts[numDataPoints];
  double peak[numDataPoints];
  double errPeak[numDataPoints];
  double Signif1[numDataPoints];
  double Signif1Err[numDataPoints];
  //* Read First File
  if ( (inputFile = fopen (fileName, "r"))==NULL) {
    printf("\n Cannot open input file: %s\n\n",fileName);
    exit(0);
  }
  printf(" Voltage    Peak Value (kele)  error \n");
    int i=0;
  //for(int i=0; i<numDataPoints; i++) {
  while (!feof(inputFile)) {
    fscanf(inputFile,"%lf  %lf  %lf    \n",&volts[i],&peak[i],&errPeak[i]);
    printf("%9.4f  %9.4f  %9.4f  %9.4f\n",volts[i],peak[i],errPeak[i]);

    peak[i]*=RFACTOR;
    errPeak[i]=RFACTOR*sqrt(errPeak[i]*errPeak[i]+VSYSTEMATIC*VSYSTEMATIC);
    errVolts[i]=0.;
    i++;
  }
  int NumberOfPointsRead = i;
  cout << "Number of DataPoints read = " << i << endl;
  fclose(inputFile);

//   //* Read Second File
//   //char fileName2[120]="./inputFile10.txt";
//   char fileName2[120]="./inputfile10pol1.txt";// -10 C
//   //char fileName2[120]="./inputfile10pol2.txt";// -10 C
  
//   double volts10[numDataPoints];
//   double errVolts10[numDataPoints];
//   double peak10[numDataPoints];
//   double errPeak10[numDataPoints];
//   if ( (inputFile = fopen (fileName2, "r"))==NULL) {
//     printf("\n Cannot open input file: %s\n\n",fileName);
//     exit(0);
//   }
//   printf(" Voltage    Peak Value (kele)  error \n");
//     int i=0;
//   //for(int i=0; i<numDataPoints; i++) {
//   while (!feof(inputFile)) {
//     fscanf(inputFile,"%lf  %lf  %lf    \n",&volts10[i],&peak10[i],&errPeak10[i]);
//     printf("%9.4f  %9.4f  %9.4f  %9.4f\n",volts10[i],peak10[i],errPeak10[i]);

//     peak10[i]*=RFACTOR10;
//     errPeak10[i]=RFACTOR*sqrt(errPeak10[i]*errPeak10[i]+VSYSTEMATIC*VSYSTEMATIC);
//     errVolts10[i]=0.;
//     i++;
//   }
//   int NumberOfPointsRead10 = i;
//   cout << "Number of DataPoints read = " << i << endl;
//   fclose(inputFile);
  
  
  //* Set some common options
  //*********************************************************
  
  char plotName[120]="fitted_escale";
  
  
  //* create some canvas
  TCanvas *c1 = new TCanvas();
  //c1->SetGrid();
  //gStyle->SetOptStat(00);
  char ytit[15];
  

  double markerSize=1.4;
  
  //* For data v mc OR calibrated data,MC:
  float maxGraph=40.0;
  float minGraph=0;
  
  
  data_v_mcGraph_error = new TGraphErrors(NumberOfPointsRead,volts,peak,errVolts,errPeak);
  data_v_mcGraph_error->SetTitle(0);
  data_v_mcGraph_error->SetMarkerSize(markerSize);
  data_v_mcGraph_error->SetMarkerStyle(22);
  data_v_mcGraph_error->SetMaximum(maxGraph);
  data_v_mcGraph_error->SetMinimum(minGraph);
  
  data_v_mcGraph_error->Draw("AP");
  data_v_mcGraph_error->GetYaxis()->SetTitleOffset(1.00); //ATLAS Style
  data_v_mcGraph_error->GetXaxis()->SetTitle("Bias Voltage (V)");
  data_v_mcGraph_error->GetXaxis()->SetLabelSize(0.06);
  data_v_mcGraph_error->GetYaxis()->SetLabelSize(0.06);
  data_v_mcGraph_error->GetXaxis()->SetTitleSize(0.06);
  data_v_mcGraph_error->GetYaxis()->SetTitleSize(0.06);
  data_v_mcGraph_error->GetYaxis()->SetTitle("Number of electrons (#times10^{3})");
  data_v_mcGraph_error->Draw("P");
  
  //TLine *line0 = new TLine(0.,1.,275.,1.);
  //line0->Draw();
  
  c1->Update();
  std::cout << "press return to continue..." << std::endl;
  getchar();
  
//   data_v_mcGraph_error = new TGraphErrors(NumberOfPointsRead10,volts10,peak10,errVolts10,errPeak10);
//   data_v_mcGraph_error->SetTitle(0);
//   data_v_mcGraph_error->SetMarkerSize(markerSize);
//   data_v_mcGraph_error->SetMarkerStyle(22);
//   data_v_mcGraph_error->Draw("P");



float textSize=0.05;
char etaBlaBla[100];
TLatex *legen = new TText(1.,1.,"legen"); 
legen->SetNDC();
legen->SetTextSize(textSize);

sprintf(etaBlaBla,"Sensor T=-8.5 ^{o}C, Ambient T=-24 ^{o}C");
legen->DrawLatex(0.27, 0.88,etaBlaBla);
TMarker *mark1 = new TMarker(0.25,0.90,22);
mark1->SetNDC(kTRUE);
mark1->SetMarkerSize(2.0);
mark1->Draw();

// sprintf(etaBlaBla,"Sensor T= 5.0 ^{o}C, Ambient T=-10 ^{o}C");
// legen->DrawLatex(0.27, 0.83,etaBlaBla);
// TMarker *mark2 = new TMarker(0.25,0.85,22);
// mark2->SetNDC(kTRUE);
// mark2->SetMarkerSize(2.0);
// mark2->Draw();

// sprintf(etaBlaBla,"Signal = 42, Bgnd error");
// legen->DrawLatex(0.57, 0.78,etaBlaBla);
// TMarker *mark3 = new TMarker(0.55,0.80,24);
// mark3->SetNDC(kTRUE);
// mark3->SetMarkerSize(2.0);
// mark3->Draw();

// sprintf(etaBlaBla,"Signal = 42, Poisson only");
// legen->DrawLatex(0.57, 0.73,etaBlaBla);
// TMarker *mark4 = new TMarker(0.55,0.75,20);
// mark4->SetNDC(kTRUE);
// mark4->SetMarkerSize(2.0);
// mark4->Draw();


c1->Update();



char outfileName[120]="Nelectrons_vs_Voltage.png";
c1->Print(outfileName);



  getchar();
  
  c1->Close();

  return 0;
}
